dolphin-plugins: update to 20.08.0

closes #24333
This commit is contained in:
Domenico Panella 2020-08-17 21:33:31 +02:00 committed by John
parent 9c7f5848f9
commit 8d5952a263
2 changed files with 67 additions and 3 deletions

View File

@ -0,0 +1,64 @@
Author: @Johnnynator
Reason: musl defines stderr/out as (stderr)
---
diff -u -r svn.bak/svncleanupdialog.cpp svn/svncleanupdialog.cpp
--- svn.bak/svncleanupdialog.cpp 2020-08-18 21:40:19.812711204 +0200
+++ svn/svncleanupdialog.cpp 2020-08-18 21:43:40.088090871 +0200
@@ -74,7 +74,7 @@
emit operationCompletedMessage(i18nc("@info:status", "SVN clean up completed successfully."));
} else {
emit errorMessage(i18nc("@info:status", "SVN clean up failed for %1", workDir));
- qDebug() << result.stderr;
+ qDebug() << result.serr;
}
QDialog::accept();
diff -u -r svn.bak/svncommands.h svn/svncommands.h
--- svn.bak/svncommands.h 2020-08-18 21:40:19.811711222 +0200
+++ svn/svncommands.h 2020-08-18 21:43:40.089090854 +0200
@@ -35,8 +35,8 @@
*/
struct CommandResult {
bool success; ///< True if return code is '0' (normal execution).
- QString stdout; ///< Process stdout.
- QString stderr; ///< Process stderr.
+ QString sout; ///< Process stdout.
+ QString serr; ///< Process stderr.
};
/**
diff -u -r svn.bak/svnprogressdialog.cpp svn/svnprogressdialog.cpp
--- svn.bak/svnprogressdialog.cpp 2020-08-18 21:40:19.811711222 +0200
+++ svn/svnprogressdialog.cpp 2020-08-18 21:43:40.088090871 +0200
@@ -115,7 +115,7 @@
const CommandResult result = SvnCommands::cleanup(m_workingDir);
if (!result.success) {
qWarning() << QString("'svn cleanup' failed for %1").arg(m_workingDir);
- qWarning() << result.stderr;
+ qWarning() << result.serr;
}
m_svnTerminated = false;
}

View File

@ -1,7 +1,7 @@
# Template file for 'dolphin-plugins'
pkgname=dolphin-plugins
version=20.04.3
revision=2
version=20.08.0
revision=1
build_style=cmake
hostmakedepends="extra-cmake-modules gettext qt5-qmake qt5-host-tools kcoreaddons kconfig"
makedepends="qt5-devel kxmlgui-devel kio-devel ktexteditor-devel dolphin"
@ -10,4 +10,4 @@ maintainer="Domenico Panella <pandom79@gmail.com>"
license="GPL-2.0-or-later"
homepage="https://kde.org/applications/en/system/org.kde.dolphin_plugins"
distfiles="${KDE_SITE}/release-service/${version}/src/${pkgname}-${version}.tar.xz"
checksum=f0dad66e7302711e136b0253fb73dbf16bc9facdbb4ad617207fb818fc84130a
checksum=a8a0c35f75eb8e63ee90f44ce930babceff86676b8bba213c82b7ffb29e526bb
diff -u -r svn.bak/svncommands.cpp svn/svncommands.cpp
--- svn.bak/svncommands.cpp 2020-08-18 21:40:19.809711258 +0200
+++ svn/svncommands.cpp 2020-08-18 21:43:40.090090838 +0200
@@ -311,8 +311,8 @@
} else {
result.success = true;
}
- result.stdout = process.readAllStandardOutput();
- result.stderr = process.readAllStandardError();
+ result.sout = process.readAllStandardOutput();
+ result.serr = process.readAllStandardError();
return result;
}
@@ -399,7 +399,7 @@
if (!process.waitForFinished() || process.exitCode() != 0) {
process.setReadChannel( QProcess::StandardError );
// If stderr contains 'E195012' that means repo doesn't exist in the revision range.
// It's not an error: let's return everything we've got already.
const QLatin1String errorCode("svn: E195012:"); // Error: 'Unable to find repository location for <path> in revision <revision>'.
if (QTextStream(&process).readAll().indexOf(errorCode) != -1) {
@@ -399,7 +399,7 @@
if (!process.waitForFinished() || process.exitCode() != 0) {
process.setReadChannel( QProcess::StandardError );
- // If stderr contains 'E195012' that means repo doesn't exist in the revision range.
+ // If serr contains 'E195012' that means repo doesn't exist in the revision range.
// It's not an error: let's return everything we've got already.
const QLatin1String errorCode("svn: E195012:"); // Error: 'Unable to find repository location for <path> in revision <revision>'.